@@ -64,7 +64,7 @@ class DateParserSv(DateParser):
         u'c:a'     : Date.MOD_ABOUT
         }
 
-    bce = ["f Kr"]
+    bce = [u"f Kr"]
 
     calendar_to_int = {
         u'gregoriansk   '      : Date.CAL_GREGORIAN, 
@@ -128,20 +128,20 @@ class DateDisplaySv(DateDisplay):
         )
 
     calendar = (
-        "", 
-        " (juliansk)", 
-        " (hebreisk)", 
-        " (fransk republikansk)", 
-        " (persisk)", 
-        " (islamisk)", 
-        " (svensk)"
+        u"", 
+        u"juliansk", 
+        u"hebreisk", 
+        u"fransk republikansk", 
+        u"persisk", 
+        u"islamisk", 
+        u"svensk"
         )
     
-    _mod_str = ("", u"före ", u"efter ", u"c:a ", "", "", "")
+    _mod_str = (u"", u"före ", u"efter ", u"c:a ", u"", u"", u"")
 
-    _qual_str = ("", u"uppskattat ", u"beräknat ")
+    _qual_str = (u"", u"uppskattat ", u"beräknat ")
     
-    _bce_str = "%s f Kr"
+    _bce_str = u"%s f Kr"
 
     def display(self, date):
         """
@@ -151,6 +151,7 @@ class DateDisplaySv(DateDisplay):
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = self._qual_str[qual]
 
@@ -161,16 +162,19 @@ class DateDisplaySv(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return u"%sfrån %s till %s%s" % (qual_str, d1, d2, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return u"%sfrån %s till %s%s" % (qual_str, d1, d2, scal)
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
+            scal = self.format_extras(cal, newyear)
             return u"%smellan %s och %s%s" % (qual_str, d1, d2, 
-                                              self.calendar[cal])
+                                              scal)
         else:
             text = self.display_cal[date.get_calendar()](start)
+            scal = self.format_extras(cal, newyear)
             return u"%s%s%s%s" % (qual_str, self._mod_str[mod], 
-                                 text, self.calendar[cal])
+                                 text, scal)
 
 #-------------------------------------------------------------------------
 #
