@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _ChildHasIdOf.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _ChildHasIdOf.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -46,7 +46,7 @@ class ChildHasIdOf(HasGrampsId):
     labels      = [ _('Person ID:') ]
     name        = _('Families with child with the <Id>')
     description = _("Matches families where child has a specified "
-                    "GRAMPS ID")
+                    "Gramps ID")
     category    = _('Child filters')
     base_class = HasGrampsId
     apply = child_base
