@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasNoteRegexp.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _MatchesRegexpOf.py 15596 2010-06-28 07:28:16Z ldnp $
 
 #-------------------------------------------------------------------------
 #
@@ -27,7 +27,7 @@
 #
 #-------------------------------------------------------------------------
 import re
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -57,7 +57,7 @@ class MatchesRegexpOf(Rule):
             
     def apply(self, db, note):
         """ Apply the filter """
-        text = unicode(note.get())
-        if self.match.match(text) != None:
+        text = note.get()
+        if self.match.match(text) is not None:
             return True
         return False
