@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasFamilyEvent.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _HasFamilyEvent.py 15368 2010-05-09 13:42:33Z dsblank $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -64,6 +64,8 @@ class HasFamilyEvent(Rule):
     def apply(self,db,person):
         for f_id in person.get_family_handle_list():
             f = db.get_family_from_handle(f_id)
+            if not f:
+                continue
             for event_ref in f.get_event_ref_list():
                 if not event_ref:
                     continue
