@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasSource.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: _HasSource.py 14905 2010-03-22 17:15:00Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -43,5 +43,5 @@ from Filters.Rules._HasSourceBase import HasSourceBase
 class HasSource(HasSourceBase):
     """People with sources"""
 
-    name        = _('People with <count> source')
-    description = _("Matches people with a certain number of items in the source")
+    name        = _('People with <count> sources')
+    description = _("Matches people with a certain number of sources connected to it")
