@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _MediaSidebarFilter.py 10339 2008-03-19 11:32:18Z bmcage $
+# $Id: _MediaSidebarFilter.py 14248 2010-02-06 16:08:10Z dsblank $
 
 #-------------------------------------------------------------------------
 #
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -67,7 +67,7 @@ class MediaSidebarFilter(SidebarFilter):
 
         self.generic = gtk.ComboBox()
 
-        SidebarFilter.__init__(self, dbstate, uistate)
+        SidebarFilter.__init__(self, dbstate, uistate, "MediaObject")
 
     def create_widget(self):
         cell = gtk.CellRendererText()
@@ -83,7 +83,7 @@ class MediaSidebarFilter(SidebarFilter):
         self.add_text_entry(_('Path'), self.filter_path)
         self.add_text_entry(_('Date'), self.filter_date)
         self.add_text_entry(_('Note'), self.filter_note)
-        self.add_entry(_('Custom filter'), self.generic)
+        self.add_filter_entry(_('Custom filter'), self.generic)
         self.add_entry(None, self.filter_regex)
 
     def clear(self, obj):
