@@ -4,6 +4,7 @@
 # Copyright (C) 2007-2008  Brian G. Matherly
 # Copyright (C) 2007-2009  Stephane Charette
 # Copyright (C) 2009       Gary Burton
+# Contribution 2009 by     Bob Ham <rah@bash.sh>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _GraphvizReportDialog.py 12595 2009-05-30 11:58:03Z gburto01 $
+# $Id: _GraphvizReportDialog.py 15958 2010-10-08 13:53:49Z ldnp $
 
 #------------------------------------------------------------------------
 #
@@ -32,7 +33,9 @@ import tempfile
 import threading
 import time
 from types import ClassType, InstanceType
-from gettext import gettext as _
+from gen.ggettext import gettext as _
+from subprocess import Popen, PIPE
+import sys
 
 #-------------------------------------------------------------------------------
 #
@@ -47,19 +50,20 @@ import gobject
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------------
-import Mime
 import Utils
-import BaseDoc
-import Config
+from gui.utils import ProgressMeter, open_file_with_default_application
+from gen.plug.docgen import BaseDoc, GVDoc 
+import config
 from ReportBase import CATEGORY_GRAPHVIZ
 from _ReportDialog import ReportDialog
 from _PaperMenu import PaperFrame
 from gen.plug.menu import NumberOption, TextOption, EnumeratedListOption, \
                           BooleanOption
+import constfunc
 
 #-------------------------------------------------------------------------------
 #
-# Private Contstants
+# Private Constants
 #
 #-------------------------------------------------------------------------------
 _FONTS = [ { 'name' : _("Default"),                   'value' : ""          },
@@ -87,7 +91,7 @@ _RATIO = [ { 'name' : _("Minimal size"),                'value': "compress" },
 _NOTELOC = [ { 'name' : _("Top"),    'value' : "t" },
              { 'name' : _("Bottom"), 'value' : "b" }]
 
-if os.sys.platform == "win32":
+if constfunc.win():
     _DOT_FOUND = Utils.search_for("dot.exe")
     
     if Utils.search_for("gswin32c.exe") == 1:
@@ -124,9 +128,9 @@ def _run_long_process_in_thread(func, header):
     @return: nothing
     
     """
-    pbar = Utils.ProgressMeter(_('Processing File'))
+    pbar = ProgressMeter(_('Processing File'))
     pbar.set_pass(total=40, 
-                  mode=Utils.ProgressMeter.MODE_ACTIVITY, 
+                  mode=ProgressMeter.MODE_ACTIVITY, 
                   header=header)
     
     sys_thread = threading.Thread(target=func)
@@ -146,14 +150,14 @@ def _run_long_process_in_thread(func, header):
 # GVDocBase
 #
 #-------------------------------------------------------------------------------
-class GVDocBase(BaseDoc.BaseDoc, BaseDoc.GVDoc):
+class GVDocBase(BaseDoc, GVDoc):
     """
-    Base document generator for all Graphiz document generators. Classes that
+    Base document generator for all Graphviz document generators. Classes that
     inherit from this class will only need to implement the close function.
     The close function will generate the actual file of the appropriate type.
     """
     def __init__(self, options, paper_style):
-        BaseDoc.BaseDoc.__init__(self, None, paper_style, None)
+        BaseDoc.__init__(self, None, paper_style)
 
         self._filename      = None
         self._dot           = StringIO()
@@ -194,8 +198,8 @@ class GVDocBase(BaseDoc.BaseDoc, BaseDoc.GVDoc):
         xmargin = self._paper.get_left_margin() / 2.54
         ymargin = self._paper.get_top_margin() / 2.54
 
-        sizew = sizew * self.hpages         
-        sizeh = sizeh * self.vpages
+        sizew *= self.hpages         
+        sizeh *= self.vpages
                       
         self.write( 'digraph GRAMPS_graph\n'        )
         self.write( '{\n'                           )
@@ -220,8 +224,7 @@ class GVDocBase(BaseDoc.BaseDoc, BaseDoc.GVDoc):
         self.write( '  size="%3.2f,%3.2f"; \n'      % (sizew, sizeh)    )
         self.write( '  splines="true";\n'           )
         self.write( '\n'                            )
-        self.write( '  edge [len=0.5 style=solid arrowhead=none '
-                            'arrowtail=normal fontsize=%d];\n' % self.fontsize )
+        self.write( '  edge [len=0.5 style=solid fontsize=%d];\n' % self.fontsize )
         if self.fontfamily:
             self.write( '  node [style=filled fontname="%s" fontsize=%d];\n' 
                             % ( self.fontfamily, self.fontsize ) )
@@ -235,7 +238,7 @@ class GVDocBase(BaseDoc.BaseDoc, BaseDoc.GVDoc):
         self._dot.write(text.encode('utf8', 'xmlcharrefreplace'))
 
     def open(self, filename):
-        """ Implement BaseDoc.BaseDoc.open() """
+        """ Implement BaseDoc.open() """
         self._filename = os.path.normpath(os.path.abspath(filename))
 
     def close(self):
@@ -268,7 +271,7 @@ class GVDocBase(BaseDoc.BaseDoc, BaseDoc.GVDoc):
         Add a node to this graph. Nodes can be different shapes like boxes and
         circles.
         
-        Implements BaseDoc.GVDoc.add_node().
+        Implements GVDoc.add_node().
         """
         text = '['
 
@@ -302,20 +305,29 @@ class GVDocBase(BaseDoc.BaseDoc, BaseDoc.GVDoc):
         """
         Add a link between two nodes.
         
-        Implementes BaseDoc.GVDoc.add_link().
+        Implements GVDoc.add_link().
         """
         self.write('  %s -> %s' % (id1, id2))
         
         if style or head or tail:
             self.write(' [')
-            
+
             if style:
                 self.write(' style=%s' % style)
             if head:
                 self.write(' arrowhead=%s' % head)
             if tail:
                 self.write(' arrowtail=%s' % tail)
-                
+            if head:
+                if tail:
+                    self.write(' dir=both')
+                else:
+                    self.write(' dir=forward')
+            else:
+                if tail:
+                    self.write(' dir=back')
+                else:
+                    self.write(' dir=none')                
             self.write(' ]')
 
         self.write(';')
@@ -329,7 +341,7 @@ class GVDocBase(BaseDoc.BaseDoc, BaseDoc.GVDoc):
         """
         Add a comment.
         
-        Implementes BaseDoc.GVDoc.add_comment().
+        Implements GVDoc.add_comment().
         """
         tmp = comment.split('\n')
         for line in tmp:
@@ -342,13 +354,13 @@ class GVDocBase(BaseDoc.BaseDoc, BaseDoc.GVDoc):
                 self.write('# %s\n' % text)
 
     def start_subgraph(self, graph_id):
-        """ Implement BaseDoc.GVDoc.start_subgraph() """
+        """ Implement GVDoc.start_subgraph() """
         self.write('  subgraph cluster_%s\n' % graph_id)
         self.write('  {\n')
         self.write('  style="invis";\n') # no border around subgraph (#0002176)
     
     def end_subgraph(self):
-        """ Implement BaseDoc.GVDoc.end_subgraph() """
+        """ Implement GVDoc.end_subgraph() """
         self.write('  }\n')
 
 #-------------------------------------------------------------------------------
@@ -380,7 +392,7 @@ class GVDotDoc(GVDocBase):
         dotfile.close()
         
         if self.open_req:
-            Utils.open_file_with_default_application(self._filename) 
+            open_file_with_default_application(self._filename) 
 
 #-------------------------------------------------------------------------------
 #
@@ -436,13 +448,21 @@ class GVPsDoc(GVDocBase):
         # but the output is clipped, some margins have disappeared. I used 1 inch margins always.
         # See bug tracker issue 2815
 
-        os.system( 'dot -Tps:cairo -o"%s" "%s"' % (self._filename, tmp_dot) )
-        
+        # Covert filename to str using file system encoding.
+        fname = self._filename.encode(sys.getfilesystemencoding())
+
+        command = 'dot -Tps:cairo -o"%s" "%s"' % (fname, tmp_dot)
+        dotversion = Popen(['dot', '-V'], stderr=PIPE).communicate(input=None)[1]
+        # Problem with dot 2.26.3 and multiple pages, which gives "cairo: out of memory"
+        # If the :cairo is skipped for these cases it gives acceptable result.
+        if dotversion.find('2.26.3') != -1 and (self.vpages * self.hpages) > 1:
+            command=command.replace(':cairo','')
+        os.system(command)
         # Delete the temporary dot file
         os.remove(tmp_dot)
         
         if self.open_req:
-            Utils.open_file_with_default_application(self._filename)
+            open_file_with_default_application(self._filename)
 
 #-------------------------------------------------------------------------------
 #
@@ -480,15 +500,17 @@ class GVSvgDoc(GVDocBase):
         dotfile = os.fdopen(handle,"w")
         dotfile.write(self._dot.getvalue())
         dotfile.close()
+        # Covert filename to str using file system encoding.
+        fname = self._filename.encode(sys.getfilesystemencoding())
 
         # Generate the SVG file.
-        os.system( 'dot -Tsvg -o"%s" "%s"' % (self._filename, tmp_dot) )
+        os.system( 'dot -Tsvg -o"%s" "%s"' % (fname, tmp_dot) )
         
         # Delete the temporary dot file
         os.remove(tmp_dot)
         
         if self.open_req:
-            Utils.open_file_with_default_application(self._filename)
+            open_file_with_default_application(self._filename)
             
 #-------------------------------------------------------------------------------
 #
@@ -526,15 +548,17 @@ class GVSvgzDoc(GVDocBase):
         dotfile = os.fdopen(handle,"w")
         dotfile.write(self._dot.getvalue())
         dotfile.close()
+        # Covert filename to str using file system encoding.
+        fname = self._filename.encode(sys.getfilesystemencoding())
         
         # Generate the SVGZ file.
-        os.system( 'dot -Tsvgz -o"%s" "%s"' % (self._filename, tmp_dot) )
+        os.system( 'dot -Tsvgz -o"%s" "%s"' % (fname, tmp_dot) )
         
         # Delete the temporary dot file
         os.remove(tmp_dot)
         
         if self.open_req:
-            Utils.open_file_with_default_application(self._filename)
+            open_file_with_default_application(self._filename)
 
 #-------------------------------------------------------------------------------
 #
@@ -572,15 +596,17 @@ class GVPngDoc(GVDocBase):
         dotfile = os.fdopen(handle,"w")
         dotfile.write(self._dot.getvalue())
         dotfile.close()
+        # Covert filename to str using file system encoding.
+        fname = self._filename.encode(sys.getfilesystemencoding())
         
         # Generate the PNG file.
-        os.system( 'dot -Tpng -o"%s" "%s"' % (self._filename, tmp_dot) )
+        os.system( 'dot -Tpng -o"%s" "%s"' % (fname, tmp_dot) )
         
         # Delete the temporary dot file
         os.remove(tmp_dot)
         
         if self.open_req:
-            Utils.open_file_with_default_application(self._filename)     
+            open_file_with_default_application(self._filename)     
 
 #-------------------------------------------------------------------------------
 #
@@ -618,15 +644,17 @@ class GVJpegDoc(GVDocBase):
         dotfile = os.fdopen(handle,"w")
         dotfile.write(self._dot.getvalue())
         dotfile.close()
+        # Covert filename to str using file system encoding.
+        fname = self._filename.encode(sys.getfilesystemencoding())
         
         # Generate the JPEG file.
-        os.system( 'dot -Tjpg -o"%s" "%s"' % (self._filename, tmp_dot) )
+        os.system( 'dot -Tjpg -o"%s" "%s"' % (fname, tmp_dot) )
         
         # Delete the temporary dot file
         os.remove(tmp_dot)
         
         if self.open_req:
-            Utils.open_file_with_default_application(self._filename)
+            open_file_with_default_application(self._filename)
 
 #-------------------------------------------------------------------------------
 #
@@ -664,15 +692,17 @@ class GVGifDoc(GVDocBase):
         dotfile = os.fdopen(handle,"w")
         dotfile.write(self._dot.getvalue())
         dotfile.close()
+        # Covert filename to str using file system encoding.
+        fname = self._filename.encode(sys.getfilesystemencoding())
         
         # Generate the GIF file.
-        os.system( 'dot -Tgif -o"%s" "%s"' % (self._filename, tmp_dot) )
+        os.system( 'dot -Tgif -o"%s" "%s"' % (fname, tmp_dot) )
         
         # Delete the temporary dot file
         os.remove(tmp_dot)
         
         if self.open_req:
-            Utils.open_file_with_default_application(self._filename)     
+            open_file_with_default_application(self._filename)     
 
 #-------------------------------------------------------------------------------
 #
@@ -713,15 +743,18 @@ class GVPdfGvDoc(GVDocBase):
         dotfile = os.fdopen(handle,"w")
         dotfile.write(self._dot.getvalue())
         dotfile.close()
-        
+        # Covert filename to str using file system encoding.
+        fname = self._filename.encode(sys.getfilesystemencoding())
         # Generate the PDF file.
-        os.system( 'dot -Tpdf -o"%s" "%s"' % (self._filename, tmp_dot) )
-        
+        command = 'dot -Tpdf -o"%s" "%s"' % (fname, tmp_dot)
+
+        os.system( command )
+
         # Delete the temporary dot file
         os.remove(tmp_dot)
-        
+
         if self.open_req:
-            Utils.open_file_with_default_application(self._filename)
+            open_file_with_default_application(self._filename)
 
 #-------------------------------------------------------------------------------
 #
@@ -766,6 +799,11 @@ class GVPdfGsDoc(GVDocBase):
         # Reason for using -Tps:cairo. Needed for Non Latin-1 letters
         # See bug tracker issue 2815
         command = 'dot -Tps:cairo -o"%s" "%s"' % ( tmp_ps, tmp_dot )
+        dotversion = Popen(['dot', '-V'], stderr=PIPE).communicate(input=None)[1]
+        # Problem with dot 2.26.3 and multiple pages, which gives "cairo: out of memory"
+        # If the :cairo is skipped for these cases it gives acceptable result.
+        if dotversion.find('2.26.3') != -1 and (self.vpages * self.hpages) > 1:
+            command=command.replace(':cairo','')
         os.system(command)
         
         # Add .5 to remove rounding errors.
@@ -774,16 +812,18 @@ class GVPdfGsDoc(GVDocBase):
         height_pt = int( (paper_size.get_height_inches() * 72) + 0.5 )
         
         # Convert to PDF using ghostscript
+        fname = self._filename.encode(sys.getfilesystemencoding())
         command = '%s -q -sDEVICE=pdfwrite -dNOPAUSE -dDEVICEWIDTHPOINTS=%d' \
                   ' -dDEVICEHEIGHTPOINTS=%d -sOutputFile="%s" "%s" -c quit' \
-                  % ( _GS_CMD, width_pt, height_pt, self._filename, tmp_ps )
+                  % ( _GS_CMD, width_pt, height_pt, fname, tmp_ps )
+
         os.system(command)
         
         os.remove(tmp_ps)
         os.remove(tmp_dot)
         
         if self.open_req:
-            Utils.open_file_with_default_application(self._filename) 
+            open_file_with_default_application(self._filename) 
 
 #-------------------------------------------------------------------------------
 #
@@ -821,7 +861,7 @@ if _DOT_FOUND:
     
     _FORMATS += [{ 'type' : "svgz",
                    'ext'  : "svgz",
-                   'descr': _("Compressed Structured Vector Graphs (SVG)"), 
+                   'descr': _("Compressed Structured Vector Graphs (SVGZ)"), 
                    'mime' : "image/svgz", 
                    'class': GVSvgzDoc }]
     
@@ -865,7 +905,6 @@ class GraphvizFormatComboBox(gtk.ComboBox):
         self.pack_start(cell, True)
         self.add_attribute(cell, 'text', 0)
 
-        out_pref = Config.get(Config.OUTPUT_PREFERENCE)
         index = 0
         active_index = 0
         for item in _FORMATS:
@@ -873,9 +912,7 @@ class GraphvizFormatComboBox(gtk.ComboBox):
             self.store.append(row=[name])
             if item['type'] == active:
                 active_index = index
-            elif not active and name == out_pref:
-                active_index = index
-            index = index + 1
+            index += 1
         self.set_active(active_index)
 
     def get_label(self):
@@ -896,19 +933,8 @@ class GraphvizFormatComboBox(gtk.ComboBox):
     def get_format_str(self):
         return _FORMATS[self.get_active()]["type"]
 
-    def get_printable(self):
-        _apptype = _FORMATS[self.get_active()]["mime"]
-        print_label = None
-        try:
-            mprog = Mime.get_application(_apptype)
-            if Utils.search_for(mprog[0]):
-                print_label = _("Open in %(program_name)s") % { 'program_name':
-                                                                mprog[1] }
-            else:
-                print_label = None
-        except:
-            print_label = None
-        return print_label
+    def is_file_output(self):
+        return True
 
     def get_clname(self):
         return _FORMATS[self.get_active()]["type"]
@@ -922,7 +948,7 @@ class GraphvizReportDialog(ReportDialog):
     """A class of ReportDialog customized for graphviz based reports."""
     def __init__(self, dbstate, uistate, opt, name, translated_name):
         """Initialize a dialog to request that the user select options
-        for a graphiz report.  See the ReportDialog class for
+        for a graphviz report.  See the ReportDialog class for
         more information."""
         self.category = CATEGORY_GRAPHVIZ
         ReportDialog.__init__(self, dbstate, uistate, opt,
@@ -931,11 +957,11 @@ class GraphvizReportDialog(ReportDialog):
     def init_options(self, option_class):
         try:
             if (issubclass(option_class, object) or     # New-style class
-              isinstance(options_class, ClassType)):    # Old-style class
+              isinstance(options_class, ClassType)):     # Old-style class
                 self.options = option_class(self.raw_name,
                                         self.dbstate.get_database())
         except TypeError:
-            self.options = option_class    
+            self.options = option_class        
 
         ################################
         category = _("GraphViz Layout")
@@ -1096,8 +1122,8 @@ class GraphvizReportDialog(ReportDialog):
                         yoptions=gtk.SHRINK)
         self.row += 1
 
-        self.print_report = gtk.CheckButton(_("Open with application"))
-        self.tbl.attach(self.print_report, 2, 4, self.row, self.row+1,
+        self.open_with_app = gtk.CheckButton(_("Open with default viewer"))
+        self.tbl.attach(self.open_with_app, 2, 4, self.row, self.row+1,
                         yoptions=gtk.SHRINK)
         self.row += 1
 
@@ -1106,8 +1132,8 @@ class GraphvizReportDialog(ReportDialog):
             ext = ""
         else:
             spath = self.get_default_directory()
-            base = self.get_default_basename()
-            spath = os.path.normpath("%s/%s%s" % (spath, base, ext))
+            base = "%s%s" % (self.raw_name, ext)
+            spath = os.path.normpath(os.path.join(spath, base))
             self.target_fileentry.set_filename(spath)
                 
     def setup_report_options_frame(self):
@@ -1135,8 +1161,7 @@ class GraphvizReportDialog(ReportDialog):
         paper size/orientation options, but it does need a template
         file.  Those chances are made here.
         """
-        self.print_report.set_label (_("Open with default application"))
-        self.print_report.set_sensitive(True)
+        self.open_with_app.set_sensitive(True)
             
         fname = self.target_fileentry.get_full_path(0)
         (spath, ext) = os.path.splitext(fname)
@@ -1157,7 +1182,7 @@ class GraphvizReportDialog(ReportDialog):
         
         self.options.set_document(self.doc)
 
-        if self.print_report.get_active():
+        if self.open_with_app.get_active():
             self.doc.open_requested()
             
     def on_ok_clicked(self, obj):
