@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: arghandler.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: arghandler.py 15983 2010-10-14 11:31:15Z ldnp $
 
 """
 Module responsible for handling the command line arguments for GRAMPS.
@@ -94,7 +94,9 @@ class ArgHandler(object):
         if self.errorfunc:
             self.errorfunc(string)
         else:
-            print string
+            # Need to convert to str before printing
+            # For non latin characters in Windows path/file/user names
+            print string.encode(sys.getfilesystemencoding())
 
     #-------------------------------------------------------------------------
     # Argument parser: sorts out given arguments
@@ -115,8 +117,8 @@ class ArgHandler(object):
         """
         if value is None:
             return None
+        value = Utils.get_unicode_path_from_env_var(value)
         db_path = self.__deduce_db_path(value)
-
         if db_path:
             # We have a potential database path.
             # Check if it is good.
@@ -134,6 +136,9 @@ class ArgHandler(object):
         Handle the "-i" or "--import" option.
         Only Files supported by a plugin can be imported, so not Family Trees.
         """
+        # Need to convert path/filename to unicode before openingh
+		# For non latin characters in Windows path/file/user names
+        value = Utils.get_unicode_path_from_env_var(value)
         fname = value
         fullpath = os.path.abspath(os.path.expanduser(fname))
         if not os.path.exists(fullpath):
@@ -168,16 +173,20 @@ class ArgHandler(object):
         """
         if self.gui:
             return
+        # Need to covert path/filename to unicode before openingh
+		# For non latin characters in Windows path/file/user names
+        value = Utils.get_unicode_path_from_env_var(value)
         fname = value
         fullpath = os.path.abspath(os.path.expanduser(fname))
         if os.path.exists(fullpath):
-            self.__error(_("WARNING: Output file already exist!\n"
+            self.__error(_("WARNING: Output file already exists!\n"
                     "WARNING: It will be overwritten:\n   %(name)s") % \
                     {'name' : fullpath})
             answer = None
             while not answer:
-                answer = raw_input(_('OK to overwrite? (yes/no) '))
-            if answer.upper() in ('Y', 'YES', _('YES')):
+                answer = raw_input(_('OK to overwrite? (yes/no) ') \
+                                    .encode(sys.getfilesystemencoding()))
+            if answer.upper() in ('Y', 'YES', _('YES').upper()):
                 self.__error( _("Will overwrite the existing file: %s") 
                                 % fullpath)
             else:
@@ -287,7 +296,7 @@ class ArgHandler(object):
         if self.list:
             print 'List of known family trees in your database path\n'
             for name, dirname in self.dbman.family_tree_list():
-                print dirname, ', with name ', name 
+                print dirname, ', with name ', name.encode(sys.getfilesystemencoding()) 
             sys.exit(0)
             
         if self.list_more:
@@ -310,7 +319,11 @@ class ArgHandler(object):
             self.cl_action(action, options_str)
 
         for expt in self.exports:
-            print "Exporting: file %s, format %s." % expt
+            # Need to convert path/filename to str before printing
+            # For non latin characters in Windows path/file/user names
+            fn = expt[0].encode(sys.getfilesystemencoding())
+            fmt = str(expt[1])
+            print "Exporting: file %s, format %s." % (fn, fmt)
             self.cl_export(expt[0], expt[1])
 
         if cleanup:
@@ -356,7 +369,11 @@ class ArgHandler(object):
                     sys.exit(0)
 
             for imp in self.imports:
-                print "Importing: file %s, format %s." % imp
+                # Need to covert path/filename to str before printing
+		        # For non latin characters in Windows path/file/user names
+                fn = imp[0].encode(sys.getfilesystemencoding())
+                fmt = str(imp[1])
+                print "Importing: file %s, format %s." % (fn , fmt)
                 self.cl_import(imp[0], imp[1])
 
     def __open_action(self):
@@ -480,9 +497,9 @@ class ArgHandler(object):
                 if len(pdata.id) <= 25:
                     print "   %s%s- %s" % ( pdata.id, 
                                             " " * (26 - len(pdata.id)),
-                                            pdata.name)
+                                            pdata.name.encode(sys.getfilesystemencoding()))
                 else:
-                    print "   %s\t- %s" % (pdata.id, pdata.name)
+                    print "   %s\t- %s" % (pdata.id, pdata.name.encode(sys.getfilesystemencoding()) )
 
         elif action == "tool":
             try:
@@ -517,9 +534,9 @@ class ArgHandler(object):
                 if len(pdata.id) <= 25:
                     print "   %s%s- %s" % ( pdata.id, 
                                             " " * (26 - len(pdata.id)),
-                                            pdata.name)
+                                            pdata.name.encode(sys.getfilesystemencoding()))
                 else:
-                    print "   %s\t- %s" % (pdata.id, pdata.name)
+                    print "   %s\t- %s" % (pdata.id, pdata.name.encode(sys.getfilesystemencoding()))
         else:
             print "Unknown action: %s." % action
             sys.exit(0)
