@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: const.py.in 15288 2010-04-25 07:57:05Z s_charette $
+# $Id: const.py.in 15966 2010-10-10 23:34:07Z s_charette $
 
 """
 Provides constants for other modules
@@ -41,11 +41,11 @@ from gettext import gettext as _
 #
 #-------------------------------------------------------------------------
 PROGRAM_NAME   = "Gramps"
-if "3.2.3-1" == "@" + "VERSIONSTRING" + "@":
-    VERSION        = "3.2.3"
+if "3.2.5-1" == "@" + "VERSIONSTRING" + "@":
+    VERSION        = "3.2.5"
 else:
-    VERSION        = "3.2.3-1"
-VERSION_TUPLE  = (3, 2, 3)
+    VERSION        = "3.2.5-1"
+VERSION_TUPLE  = (3, 2, 5)
 
 #-------------------------------------------------------------------------
 #
@@ -117,10 +117,7 @@ else:
 # Conversion of USER_HOME to unicode was needed to have better
 # support for non ASCII path names in Windows for the Gramps database.
 USER_HOME = unicode(USER_HOME, sys.getfilesystemencoding())
-
-# Tried also coversion of HOME_DIR, but that caused a lot of problems
-# in Windows. Leave it unconverted for now.
-#HOME_DIR = unicode(HOME_DIR, sys.getfilesystemencoding())
+HOME_DIR = unicode(HOME_DIR, sys.getfilesystemencoding())
 
 #-------------------------------------------------------------------------
 #
