@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: write.py 14984 2010-04-01 01:20:40Z dsblank $
+# $Id: write.py 16092 2010-10-31 08:38:05Z bmcage $
 
 """
 Provide the Berkeley DB (DbBsddb) database backend for GRAMPS.
@@ -58,6 +58,7 @@ from gen.db.dbconst import *
 from gen.utils.callback import Callback
 from gen.updatecallback import UpdateCallback
 import Errors
+import constfunc
 
 _LOG = logging.getLogger(DBLOGNAME)
 _MINVERSION = 9
@@ -999,7 +1000,6 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
     def close(self):
         if not self.db_is_open:
             return
-
         self.env.txn_checkpoint()
 
         self.__close_metadata()
@@ -1044,6 +1044,24 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
         self.env            = None
         self.metadata       = None
         self.db_is_open     = False
+        
+        DbBsddbRead.close(self)
+        
+        self.person_map = None
+        self.family_map = None
+        self.repository_map = None
+        self.note_map = None
+        self.place_map = None
+        self.source_map = None
+        self.media_map = None
+        self.event_map = None
+        self.reference_map_primary_map = None
+        self.reference_map_referenced_map = None
+        self.reference_map = None
+        self.undo_callback = None
+        self.redo_callback = None
+        self.undo_history_callback = None
+        self.undodb = None
 
         try:
             clear_lock_file(self.get_save_path())
@@ -1586,8 +1604,8 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
     @catch_db_error
     def transaction_commit(self, transaction, msg):
         if self._LOG_ALL:
-            LOG.debug("%s: Transaction commit '%s'\n"
-                      % (self.__class__.__name__, str(msg)))
+            _LOG.debug("%s: Transaction commit '%s'\n"
+                       % (self.__class__.__name__, str(msg)))
 
         if self.readonly:
             return
@@ -1659,25 +1677,20 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
         """
         BSDDB change log settings using new method with renamed attributes
         """
-        if db.version() < (4, 7):
-            # by the book: old method with old attribute
-            self.env.set_flags(db.DB_LOG_AUTOREMOVE, 1)
-        else: # look at python interface
-            # TODO test with new version of pybsddb
-            try:
-                # try numeric compare, just first 2 digits
-                # this won't work with something like "4.10a", but
-                # hopefully they won't do that
-                old_version = map(int, db.__version__.split(".",2)[:2]) < (4, 7)
-            except:
-                # fallback, weak string compare
-                old_version = db.__version__ < "4.7"
-            if old_version:
-                # undocumented: old method with new attribute
-                self.env.set_flags(db.DB_LOG_AUTO_REMOVE, 1)
-            else:
-                # by the book: new method with new attribute
-                self.env.log_set_config(db.DB_LOG_AUTO_REMOVE, 1)
+        autoremove_flag = None
+        autoremove_method = None
+        for flag in ["DB_LOG_AUTO_REMOVE", "DB_LOG_AUTOREMOVE"]:
+            if hasattr(db, flag):
+                autoremove_flag = getattr(db, flag)
+                break
+        for method in ["log_set_config", "set_flags"]:
+            if hasattr(self.env, method):
+                autoremove_method = getattr(self.env, method)
+                break
+        if autoremove_method and autoremove_flag:
+            autoremove_method(autoremove_flag, 1)
+        else:
+            _LOG.debug("Failed to set autoremove flag")
 
     def write_version(self, name):
         """Write version number for a newly created DB."""
@@ -1699,7 +1712,7 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
                     db.DB_INIT_LOG | db.DB_INIT_TXN | db.DB_THREAD
 
         # As opposed to before, we always try recovery on databases
-        env_flags = env_flags | db.DB_RECOVER
+        env_flags |= db.DB_RECOVER
 
         # Environment name is now based on the filename
         env_name = name
@@ -1756,8 +1769,12 @@ def write_lock_file(name):
     if not os.path.isdir(name):
         os.mkdir(name)
     f = open(os.path.join(name, DBLOCKFN), "w")
-    if os.name == 'nt':
-        text = os.environ['USERNAME']
+    if constfunc.win():
+        user = os.environ['USERNAME']
+        try:
+            host = os.environ['USERDOMAIN']
+        except:
+            host = ""
     else:
         host = os.uname()[1]
         # An ugly workaround for os.getlogin() issue with Konsole
@@ -1765,7 +1782,10 @@ def write_lock_file(name):
             user = os.getlogin()
         except:
             user = os.environ.get('USER')
+    if host:
         text = "%s@%s" % (user, host)
+    else:
+        text = user		
     # Save only the username and host, so the massage can be
     # printed with correct locale in DbManager.py when a lock is found
     f.write(text)
