@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: witness.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: witness.py 12559 2009-05-21 17:19:50Z gbritton $
 
 """
 Witness class for GRAMPS.
@@ -29,7 +29,7 @@ Witness class for GRAMPS.
 # Witness class
 #
 #-------------------------------------------------------------------------
-class Witness:
+class Witness(object):
     """This class is only present to enable db upgrade."""
     def __init__(self):
         pass
