@@ -2,6 +2,8 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2007-2008       Brian G. Matherly
+# Copyright (C) 2008            Gary Burton
+# Copyright (C) 2008            Robert Cheramy <robert@cheramy.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,12 +20,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: filter.py 10884 2008-07-20 22:03:59Z pez4brian $
+# $Id: filter.py 15382 2010-05-09 23:59:22Z dsblank $
 
 """
 Proxy class for the GRAMPS databases. Apply filter
 """
-
 #-------------------------------------------------------------------------
 #
 # GRAMPS libraries
@@ -39,30 +40,36 @@ class FilterProxyDb(ProxyDbBase):
     the user.
     """
 
-    def __init__(self, db, person_filter=None, event_filter=None):
+    def __init__(self, db, person_filter=None, event_filter=None, 
+                 note_filter=None):
         """
         Create a new PrivateProxyDb instance. 
         """
         ProxyDbBase.__init__(self, db)
         self.person_filter = person_filter
-
         if person_filter:
             self.plist = set(person_filter.apply(
-                    self.db, self.db.get_person_handles(sort_handles=False)))
+                    self.db, self.db.iter_person_handles()))
         else:
-            self.plist = self.db.get_person_handles(sort_handles=False)
+            self.plist = set(self.db.iter_person_handles())
 
         if event_filter:
             self.elist = set(event_filter.apply(
-                    self.db, self.db.get_event_handles()))
+                    self.db, self.db.iter_event_handles()))
         else:
-            self.elist = self.db.get_event_handles()
+            self.elist = set(self.db.iter_event_handles())
+        
+        if note_filter:
+            self.nlist = set(note_filter.apply(
+                    self.db, self.db.iter_note_handles()))
+        else:
+            self.nlist = set(self.db.iter_note_handles())
 
         self.flist = set()
-        for handle in list(self.plist):
+        for handle in self.plist:
             person = self.db.get_person_from_handle(handle)
-            for family_handle in person.get_family_handle_list():
-                self.flist.add(family_handle)
+            if person:
+                self.flist.update(person.get_family_handle_list())
 
     def get_person_from_handle(self, handle):
         """
@@ -71,7 +78,8 @@ class FilterProxyDb(ProxyDbBase):
         """
         if handle in self.plist:
             person = self.db.get_person_from_handle(handle)
-
+            if person is None:
+                return None
             person.set_person_ref_list(
                 [ ref for ref in person.get_person_ref_list()
                   if ref.ref in self.plist ])
@@ -96,31 +104,58 @@ class FilterProxyDb(ProxyDbBase):
                 person.set_birth_ref(bref)
             if dref in new_eref_list:
                 person.set_death_ref(dref)
-
+            
+            # Filter notes out
+            self.sanitize_person(person)
+            
             return person
         else:
             return None
 
+    def include_person(self, handle):
+        return handle in self.plist               
+
+    def include_family(self, handle):
+        return handle in self.flist               
+
+    def include_event(self, handle):
+        return handle in self.elist               
+
+    def include_note(self, handle):
+        return handle in self.nlist               
+
     def get_source_from_handle(self, handle):
         """
         Finds a Source in the database from the passed gramps' ID.
         If no such Source exists, None is returned.
         """
-        return self.db.get_source_from_handle(handle)
+        source = self.db.get_source_from_handle(handle)
+        # Filter notes out
+
+        self.sanitize_notebase(source)
+        return source
 
     def get_object_from_handle(self, handle):
         """
-        Finds an Object in the database from the passed gramps' ID.
+        Finds a MediaObject in the database from the passed GRAMPS' handle.
         If no such Object exists, None is returned.
         """
-        return self.db.get_object_from_handle(handle)
+        media = self.db.get_object_from_handle(handle)
+        # Filter notes out
+        self.sanitize_notebase(media)
+        self.sanitize_sourcebase(media)
+        return media
 
     def get_place_from_handle(self, handle):
         """
-        Finds a Place in the database from the passed gramps' ID.
+        Finds a Place in the database from the passed GRAMPS' handle.
         If no such Place exists, None is returned.
         """
-        return self.db.get_place_from_handle(handle)
+        place = self.db.get_place_from_handle(handle)
+        # Filter notes out
+        self.sanitize_notebase(place)
+        self.sanitize_sourcebase(place)
+        return place
 
     def get_event_from_handle(self, handle):
         """
@@ -128,7 +163,11 @@ class FilterProxyDb(ProxyDbBase):
         If no such Event exists, None is returned.
         """
         if handle in self.elist:
-            return self.db.get_event_from_handle(handle)
+            event = self.db.get_event_from_handle(handle)
+            # Filter all notes out
+            self.sanitize_notebase(event)
+            self.sanitize_sourcebase(event)
+            return event
         else:
             return None
 
@@ -139,7 +178,8 @@ class FilterProxyDb(ProxyDbBase):
         """
         if handle in self.flist:
             family = self.db.get_family_from_handle(handle)
-        
+            if family is None:
+                return None
             eref_list = [ eref for eref in family.get_event_ref_list()
                           if eref.ref in self.elist ]
             family.set_event_ref_list(eref_list)
@@ -153,6 +193,10 @@ class FilterProxyDb(ProxyDbBase):
             clist = [ cref for cref in family.get_child_ref_list()
                       if cref.ref in self.plist ]
             family.set_child_ref_list(clist)
+            
+            # Filter notes out
+            self.sanitize_notebase(family)
+            self.sanitize_sourcebase(family)
             return family
         else:
             return None
@@ -162,14 +206,21 @@ class FilterProxyDb(ProxyDbBase):
         Finds a Repository in the database from the passed gramps' ID.
         If no such Repository exists, None is returned.
         """
-        return self.db.get_repository_from_handle(handle)
+        repository = self.db.get_repository_from_handle(handle)
+        # Filter notes out
+        self.sanitize_notebase(repository)
+        self.sanitize_addressbase(repository)
+        return repository
 
     def get_note_from_handle(self, handle):
         """
         Finds a Note in the database from the passed gramps' ID.
         If no such Note exists, None is returned.
         """
-        return self.db.get_note_from_handle(handle)
+        if handle in self.nlist:
+            return self.db.get_note_from_handle(handle)
+        else:
+            return None
 
     def get_person_from_gramps_id(self, val):
         """
@@ -177,17 +228,17 @@ class FilterProxyDb(ProxyDbBase):
         If no such Person exists, None is returned.
         """
         person = self.db.get_person_from_gramps_id(val)
-        if person.get_handle() not in self.plist:
-            return None
-        else:
-            return person
+        if person:
+            return self.get_person_from_handle(person.get_handle())
 
     def get_family_from_gramps_id(self, val):
         """
         Finds a Family in the database from the passed GRAMPS ID.
         If no such Family exists, None is returned.
         """
-        return self.db.get_family_from_gramps_id(val)
+        family = self.db.get_family_from_gramps_id(val)
+        if family:
+            return self.get_family_from_handle(family.get_handle())
 
     def get_event_from_gramps_id(self, val):
         """
@@ -195,75 +246,75 @@ class FilterProxyDb(ProxyDbBase):
         If no such Event exists, None is returned.
         """
         event = self.db.get_event_from_gramps_id(val)
-        if event.get_handle() not in self.elist:
-            return None
-        else:
-            return event
+        if event:
+            return self.get_event_from_handle(event.get_handle())
 
     def get_place_from_gramps_id(self, val):
         """
         Finds a Place in the database from the passed gramps' ID.
         If no such Place exists, None is returned.
         """
-        return self.db.get_place_from_gramps_id(val)
+        place = self.db.get_place_from_gramps_id(val)
+        if place:
+            return self.get_place_from_handle(place.get_handle())
 
     def get_source_from_gramps_id(self, val):
         """
         Finds a Source in the database from the passed gramps' ID.
         If no such Source exists, None is returned.
         """
-        return self.db.get_source_from_gramps_id(val)
+        source = self.db.get_source_from_gramps_id(val)
+        if source:
+            return self.get_source_from_handle(source.get_handle())
 
     def get_object_from_gramps_id(self, val):
         """
         Finds a MediaObject in the database from the passed gramps' ID.
         If no such MediaObject exists, None is returned.
         """
-        return self.db.get_object_from_gramps_id(val)
+        media = self.db.get_object_from_gramps_id(val)
+        if media:
+            return self.get_object_from_handle(media.get_handle())
 
     def get_repository_from_gramps_id(self, val):
         """
         Finds a Repository in the database from the passed gramps' ID.
         If no such Repository exists, None is returned.
         """
-        return self.db.get_repository_from_gramps_id(val)
+        repository = self.db.get_repository_from_gramps_id(val)
+        if repository:
+            return self.get_repository_from_handle(repository.get_handle())
 
     def get_note_from_gramps_id(self, val):
         """
         Finds a Note in the database from the passed gramps' ID.
         If no such Note exists, None is returned.
         """
-        return self.db.get_note_from_gramps_id(val)
+        note = self.db.get_note_from_gramps_id(val)
+        if note:
+            return self.get_note_from_handle(note.get_handle())
 
     def get_person_handles(self, sort_handles=True):
         """
         Return a list of database handles, one handle for each Person in
         the database. If sort_handles is True, the list is sorted by surnames
         """
+        # FIXME: plist is not a sorted list of handles
         return list(self.plist)
 
-    def get_place_handles(self, sort_handles=True):
+    def iter_person_handles(self):
         """
-        Return a list of database handles, one handle for each Place in
-        the database. If sort_handles is True, the list is sorted by
-        Place title.
+        Return an iterator over database handles, one handle for each Person in
+        the database. 
         """
-        return self.db.get_place_handles(sort_handles)
+        return self.plist
 
-    def get_source_handles(self, sort_handles=True):
+    def iter_people(self):
         """
-        Return a list of database handles, one handle for each Source in
-        the database. If sort_handles is True, the list is sorted by
-        Source title.
+        Return an iterator over handles and objects for Persons in the database
         """
-        return self.db.get_source_handles(sort_handles)
-
-    def get_media_object_handles(self, sort_handles=True):
-        """
-        Return a list of database handles, one handle for each MediaObject in
-        the database. If sort_handles is True, the list is sorted by title.
-        """
-        return self.db.get_media_object_handles(sort_handles)
+        for handle in self.plist:
+            yield handle, self.get_person_from_handle(handle)
 
     def get_event_handles(self):
         """
@@ -271,6 +322,13 @@ class FilterProxyDb(ProxyDbBase):
         the database. 
         """
         return list(self.elist)
+        
+    def iter_event_handles(self):
+        """
+        Return an iterator over database handles, one handle for each Person in
+        the database. 
+        """
+        return self.elist        
 
     def get_family_handles(self):
         """
@@ -278,25 +336,27 @@ class FilterProxyDb(ProxyDbBase):
         the database.
         """
         return list(self.flist)
-
-    def get_repository_handles(self):
+        
+    def iter_family_handles(self):
         """
-        Return a list of database handles, one handle for each Repository in
-        the database.
+        Return an iterator over database handles, one handle for each Person in
+        the database. 
         """
-        return self.db.get_repository_handles()
+        return self.flist
 
     def get_note_handles(self):
         """
         Return a list of database handles, one handle for each Note in
         the database.
         """
-        return self.db.get_note_handles()
+        return list(self.nlist)
 
-    def get_researcher(self):
-        """returns the Researcher instance, providing information about
-        the owner of the database"""
-        return self.db.get_researcher()
+    def iter_note_handles(self):
+        """
+        Return an iterator over database handles, one handle for each Person in
+        the database. 
+        """
+        return self.nlist
 
     def get_default_person(self):
         """returns the default Person of the database"""
@@ -326,39 +386,90 @@ class FilterProxyDb(ProxyDbBase):
         """
         return handle in self.elist
 
-    def has_source_handle(self, handle):
-        """
-        returns True if the handle exists in the current Source database.
-        """
-        return self.db.has_source_handle(handle)
-
-    def has_place_handle(self, handle):
-        """
-        returns True if the handle exists in the current Place database.
-        """
-        return self.db.has_place_handle(handle)
-
     def has_family_handle(self, handle):            
         """
         returns True if the handle exists in the current Family database.
         """
-        return self.db.has_family_handle(handle)
-
-    def has_object_handle(self, handle):
-        """
-        returns True if the handle exists in the current MediaObjectdatabase.
-        """
-        return self.db.has_object_handle(handle)
-
-    def has_repository_handle(self, handle):
-        """
-        returns True if the handle exists in the current Repository database.
-        """
-        return self.db.has_repository_handle(handle)
+        return handle in self.flist
 
     def has_note_handle(self, handle):
         """
         returns True if the handle exists in the current Note database.
         """
-        return self.db.has_note_handle(handle)
+        return handle in self.nlist
 
+    def find_backlink_handles(self, handle, include_classes=None):
+        """
+        Find all objects that hold a reference to the object handle.
+        Returns an iterator over a list of (class_name, handle) tuples.
+
+        @param handle: handle of the object to search for.
+        @type handle: database handle
+        @param include_classes: list of class names to include in the results.
+                                Default: None means include all classes.
+        @type include_classes: list of class names
+        
+        This default implementation does a sequential scan through all
+        the primary object databases and is very slow. Backends can
+        override this method to provide much faster implementations that
+        make use of additional capabilities of the backend.
+
+        Note that this is a generator function, it returns a iterator for
+        use in loops. If you want a list of the results use:
+
+        >    result_list = list(find_backlink_handles(handle))
+        """
+        #FIXME: add a filter for returned handles (see private.py as an example)
+        return self.db.find_backlink_handles(handle, include_classes)
+    
+    def sanitize_notebase(self, notebase):
+        """
+        Filters notes out of the passed notebase object according to the Note Filter.
+        @param notebase: NoteBase object to clean
+        @type event: NoteBase
+        """
+        if notebase:
+            note_list = notebase.get_note_list()
+            new_note_list = [ note for note in note_list if note in self.nlist ]
+            notebase.set_note_list(new_note_list)
+     
+    def sanitize_sourcebase(self, sourcebase):
+        """
+        Filter notes out of an SourceBase object
+        @param event: SourceBase object to clean
+        @type event: SourceBase
+        """
+        if sourcebase:
+            sources = sourcebase.get_source_references()
+            for source in sources:
+                self.sanitize_notebase(source)
+            
+    def sanitize_addressbase(self, addressbase):
+        if addressbase:
+            addresses = addressbase.get_address_list()
+            for address in addresses:
+                self.sanitize_notebase(address)
+                self.sanitize_sourcebase(address)
+       
+    def sanitize_person(self, person):
+        """
+        Cleans filtered notes out of the passed person
+        @param event: Person object to clean
+        @type event: Person
+        """
+        if person:
+            # Filter note references
+            self.sanitize_notebase(person)
+            self.sanitize_sourcebase(person)
+            self.sanitize_addressbase(person)
+
+            name = person.get_primary_name()
+            self.sanitize_notebase(name)
+            self.sanitize_sourcebase(name)
+
+            altnames = person.get_alternate_names()
+            for name in altnames:
+                self.sanitize_notebase(name)
+                self.sanitize_sourcebase(name)
+
+            self.sanitize_addressbase(person)
