@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editfamily.py 14735 2010-03-10 11:39:54Z bmcage $
+# $Id: editfamily.py 16092 2010-10-31 08:38:05Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -202,7 +202,7 @@ class ChildEmbedList(EmbeddedList):
         return [(1, 0), (1, 1), (1, 2), (1, 3), (1, 4), (1, 5), (1, 6), 
                 (0, 8), (0, 9)]
 
-    def add_button_clicked(self, obj):
+    def add_button_clicked(self, obj=None):
         person = gen.lib.Person()
         autoname = config.get('behavior.surname-guessing')
         #_("Father's surname"), 
@@ -231,7 +231,7 @@ class ChildEmbedList(EmbeddedList):
     def child_ref_edited(self, person):
         self.rebuild()
 
-    def share_button_clicked(self, obj):
+    def share_button_clicked(self, obj=None):
         # it only makes sense to skip those who are already in the family
         skip_list = [self.family.get_father_handle(), \
                      self.family.get_mother_handle()] + \
@@ -253,7 +253,7 @@ class ChildEmbedList(EmbeddedList):
         SelectPerson(self.dbstate, self.uistate, self.track,
                      _("Select Child"), skip=skip_list)
 
-    def del_button_clicked(self, obj):
+    def del_button_clicked(self, obj=None):
         handle = self.get_selected()
         if handle:
             for ref in self.family.get_child_ref_list():
@@ -261,7 +261,7 @@ class ChildEmbedList(EmbeddedList):
                     self.family.remove_child_ref(ref)
             self.rebuild()
 
-    def edit_button_clicked(self, obj):
+    def edit_button_clicked(self, obj=None):
         handle = self.get_selected()
         if handle:
             self.call_edit_childref(handle)
@@ -278,7 +278,7 @@ class ChildEmbedList(EmbeddedList):
                     pass
                 break
 
-    def edit_child_button_clicked(self, obj):
+    def edit_child_button_clicked(self, obj=None):
         handle = self.get_selected()
         if handle:
             for ref in self.family.get_child_ref_list():
@@ -425,6 +425,15 @@ class EditFamily(EditPrimary):
         else:
             self.add_parent = False
 
+    def _cleanup_on_exit(self):
+        """Unset all things that can block garbage collection.
+        Finalize rest
+        """
+        #FIXME, we rebind show_all below, this prevents garbage collection of
+        #  the dialog, fix the rebind
+        self.window.show_all = None
+        EditPrimary._cleanup_on_exit(self)
+
     def empty_object(self):
         return gen.lib.Family()
 
