@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: familymodel.py 14191 2010-02-02 13:56:15Z gbritton $
+# $Id: familymodel.py 16092 2010-10-31 08:38:05Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -87,10 +87,26 @@ class FamilyModel(FlatBaseModel):
             self.column_marker_text, 
             self.column_marker_color, 
             ]
-        self.marker_color_column = 9
         FlatBaseModel.__init__(self, db, scol, order, tooltip_column=6, 
                            search=search, skip=skip, sort_map=sort_map)
 
+    def destroy(self):
+        """
+        Unset all elements that can prevent garbage collection
+        """
+        self.db = None
+        self.gen_cursor = None
+        self.map = None
+        self.fmap = None
+        self.smap = None
+        FlatBaseModel.destroy(self)
+
+    def marker_column(self):
+        """
+        Return the column for marker colour.
+        """
+        return 9
+
     def on_get_n_columns(self):
         return len(self.fmap)+1
 
