@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: peoplemodel.py 14934 2010-03-26 21:11:12Z nick-h $
+# $Id: peoplemodel.py 16092 2010-10-31 08:38:05Z bmcage $
 
 """
 TreeModel for the GRAMPS Person tree.
@@ -146,6 +146,23 @@ class PeopleBaseModel(object):
         self.lru_bdate = LRU(PeopleBaseModel._CACHE_SIZE)
         self.lru_ddate = LRU(PeopleBaseModel._CACHE_SIZE)
 
+    def destroy(self):
+        """
+        Unset all elements that can prevent garbage collection
+        """
+        self.db = None
+        self.gen_cursor = None
+        self.map = None
+        self.fmap = None
+        self.smap = None
+        self.clear_local_cache()
+
+    def marker_column(self):
+        """
+        Return the column for marker colour.
+        """
+        return 11
+
     def clear_local_cache(self, handle=None):
         """ Clear the LRU cache """
         if handle:
@@ -178,7 +195,7 @@ class PeopleBaseModel(object):
     def sort_name(self, data):
         n = Name()
         n.unserialize(data[COLUMN_NAME])
-        return (n.get_group_name(), n.get_first_name())
+        return (n.get_surname(), n.get_first_name())
 
     def column_name(self, data):
         handle = data[0]
@@ -448,7 +465,6 @@ class PersonListModel(PeopleBaseModel, FlatBaseModel):
     """
     def __init__(self, db, scol=0, order=gtk.SORT_ASCENDING, search=None,
                  skip=set(), sort_map=None):
-
         PeopleBaseModel.__init__(self, db)
         FlatBaseModel.__init__(self, db, search=search, skip=skip,
                                 tooltip_column=12,
@@ -458,11 +474,12 @@ class PersonListModel(PeopleBaseModel, FlatBaseModel):
         """ Clear the LRU cache """
         PeopleBaseModel.clear_local_cache(self, handle)
 
-    def marker_column(self):
+    def destroy(self):
         """
-        Return the column for marker colour.
+        Unset all elements that can prevent garbage collection
         """
-        return 11
+        PeopleBaseModel.destroy(self)
+        FlatBaseModel.destroy(self)
 
 class PersonTreeModel(PeopleBaseModel, TreeBaseModel):
     """
@@ -473,9 +490,17 @@ class PersonTreeModel(PeopleBaseModel, TreeBaseModel):
 
         PeopleBaseModel.__init__(self, db)
         TreeBaseModel.__init__(self, db, 12, search=search, skip=skip,
-                                marker_column=11,
                                 scol=scol, order=order, sort_map=sort_map)
 
+    def destroy(self):
+        """
+        Unset all elements that can prevent garbage collection
+        """
+        PeopleBaseModel.destroy(self)
+        self.hmap = None
+        self.number_items = None
+        TreeBaseModel.destroy(self)
+
     def _set_base_data(self):
         """See TreeBaseModel, we also set some extra lru caches
         """
