@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: $
+# $Id: Records.py 14456 2010-02-24 22:56:31Z robhealey1 $
 
 #------------------------------------------------------------------------
 #
@@ -27,28 +27,22 @@
 #
 #------------------------------------------------------------------------
 import datetime
-from TransUtils import sgettext as _
+from gen.ggettext import sgettext as _
 
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-from gen.lib import ChildRefType, Date, EventType, Name
-import BaseDoc
-from BasicUtils import name_displayer
-from DataViews import register, Gramplet
+from gen.lib import ChildRefType, Date, Name
+from gen.plug.docgen import FontStyle, ParagraphStyle, FONT_SANS_SERIF
+from gen.display.name import displayer as name_displayer
+from gen.plug import Gramplet
 from gen.plug.menu import (BooleanOption, EnumeratedListOption, 
                            FilterOption, PersonOption)
-from ReportBase import Report, ReportUtils, MenuReportOptions, \
-        CATEGORY_TEXT
-from gen.plug import PluginManager
+from ReportBase import Report, ReportUtils, MenuReportOptions
 from Utils import probably_alive
 
-MODE_GUI = PluginManager.REPORT_MODE_GUI
-MODE_BKI = PluginManager.REPORT_MODE_BKI
-MODE_CLI = PluginManager.REPORT_MODE_CLI
-
 #------------------------------------------------------------------------
 #
 # Global functions
@@ -74,9 +68,7 @@ def _find_death_date(db, person):
         event_list = person.get_primary_event_ref_list()
         for event_ref in event_list:
             event = db.get_event_from_handle(event_ref.ref)
-            if (event.get_type() == EventType.BURIAL or
-                event.get_type() == EventType.CAUSE_DEATH or
-                event.get_type() == EventType.CREMATION):
+            if event.get_type().is_death_fallback():
                 return event.get_date_object()
     return None
 
@@ -100,7 +92,7 @@ def _find_records(db, filter, callname):
     person_oldestfather = []
     person_oldestmother = []
 
-    person_handle_list = db.get_person_handles(sort_handles=False)
+    person_handle_list = db.iter_person_handles()
 
     if filter:
         person_handle_list = filter.apply(db, person_handle_list)
@@ -142,9 +134,13 @@ def _find_records(db, filter, callname):
             divorce_date = None
             for event_ref in family.get_event_ref_list():
                 event = db.get_event_from_handle(event_ref.ref)
-                if event.get_type() == EventType.MARRIAGE:
+                if (event.get_type().is_marriage() and 
+                    (event_ref.get_role().is_family() or 
+                     event_ref.get_role().is_primary())):
                     marriage_date = event.get_date_object()
-                elif event.get_type() == EventType.DIVORCE:
+                elif (event.get_type().is_divorce() and 
+                      (event_ref.get_role().is_family() or 
+                       event_ref.get_role().is_primary())):
                     divorce_date = event.get_date_object()
 
             if _good_date(marriage_date):
@@ -196,8 +192,8 @@ def _find_records(db, filter, callname):
     family_shortest = []
     family_longest = []
 
-    for family_handle in db.get_family_handles():
-        family = db.get_family_from_handle(family_handle)
+    for family in db.iter_families():
+        #family = db.get_family_from_handle(family_handle)
 
         father_handle = family.get_father_handle()
         if not father_handle:
@@ -214,21 +210,25 @@ def _find_records(db, filter, callname):
         father = db.get_person_from_handle(father_handle)
         mother = db.get_person_from_handle(mother_handle)
 
-        name = _("%s and %s") % (
-                _person_get_display_name(father, callname),
-                _person_get_display_name(mother, callname))
+        name = _("%(father)s and %(mother)s") % {
+            'father' : _person_get_display_name(father, callname), 
+            'mother' : _person_get_display_name(mother, callname) }
 
         _record(None, family_mostchildren,
                 len(family.get_child_ref_list()),
-                name, 'Family', family_handle)
+                name, 'Family', family.handle)
 
         marriage_date = None
         divorce_date = None
         for event_ref in family.get_event_ref_list():
             event = db.get_event_from_handle(event_ref.ref)
-            if event.get_type() == EventType.MARRIAGE:
+            if (event.get_type().is_marriage() and 
+                (event_ref.get_role().is_family() or 
+                 event_ref.get_role().is_primary())):
                 marriage_date = event.get_date_object()
-            elif event.get_type() == EventType.DIVORCE:
+            if (event and event.get_type().is_divorce() and 
+                (event_ref.get_role().is_family() or 
+                 event_ref.get_role().is_primary())):
                 divorce_date = event.get_date_object()
 
         father_death_date = _find_death_date(db, father)
@@ -243,7 +243,7 @@ def _find_records(db, filter, callname):
             if probably_alive(father, db) and probably_alive(mother, db):
                 _record(family_youngestmarried, family_oldestmarried,
                         today_date - marriage_date,
-                        name, 'Family', family_handle)
+                        name, 'Family', family.handle)
         elif (_good_date(divorce_date) or 
               _good_date(father_death_date) or 
               _good_date(mother_death_date)):
@@ -262,7 +262,7 @@ def _find_records(db, filter, callname):
             duration = end - marriage_date
 
             _record(family_shortest, family_longest,
-                    duration, name, 'Family', family_handle)
+                    duration, name, 'Family', family.handle)
 
     return [(text, varname, locals()[varname]) for (text, varname, default) in RECORDS]
 
@@ -326,19 +326,11 @@ class RecordsGramplet(Gramplet):
         self.set_tooltip(_("Double-click name for details"))
         self.set_text(_("No Family Tree loaded."))
 
-
     def db_changed(self):
-        self.update()
-        #self.dbstate.db.connect('person-add', self.update)
-        #self.dbstate.db.connect('person-delete', self.update)
-        #self.dbstate.db.connect('person-update', self.update)
-        #self.dbstate.db.connect('family-add', self.update)
-        #self.dbstate.db.connect('family-delete', self.update)
-        #self.dbstate.db.connect('family-update', self.update)
-
+        self.dbstate.db.connect('person-rebuild', self.update)
+        self.dbstate.db.connect('family-rebuild', self.update)
 
     def main(self):
-
         self.set_text(_("Processing...") + "\n")
         yield True
         records = _find_records(self.dbstate.db, None,
@@ -378,10 +370,9 @@ class RecordsReport(Report):
 
         self.callname = menu.get_option_by_name('callname').get_value()
 
-        self.include = {}
-        for (text, varname, default) in RECORDS:
-            self.include[varname] = menu.get_option_by_name(varname).get_value()
-
+        self.include = dict([varname,
+                            menu.get_option_by_name(varname).get_value()]
+                                for (_1, varname, _3) in RECORDS)
 
     def write_report(self):
         """
@@ -446,7 +437,7 @@ class RecordsReportOptions(MenuReportOptions):
 
         self.__filter = FilterOption(_("Filter"), 0)
         self.__filter.set_help(
-                         _("Determines what people are included in the report"))
+                         _("Determines what people are included in the report."))
         menu.add_option(category_name, "filter", self.__filter)
         self.__filter.connect('value-changed', self.__filter_changed)
         
@@ -500,31 +491,31 @@ class RecordsReportOptions(MenuReportOptions):
     def make_default_style(self, default_style):
 
         #Paragraph Styles
-        font = BaseDoc.FontStyle()
-        font.set_type_face(BaseDoc.FONT_SANS_SERIF)
+        font = FontStyle()
+        font.set_type_face(FONT_SANS_SERIF)
         font.set_size(10)
         font.set_bold(0)
-        para = BaseDoc.ParagraphStyle()
+        para = ParagraphStyle()
         para.set_font(font)
         para.set_description(_('The basic style used for the text display.'))
         default_style.add_paragraph_style('REC-Normal', para)
 
-        font = BaseDoc.FontStyle()
-        font.set_type_face(BaseDoc.FONT_SANS_SERIF)
+        font = FontStyle()
+        font.set_type_face(FONT_SANS_SERIF)
         font.set_size(10)
         font.set_bold(1)
-        para = BaseDoc.ParagraphStyle()
+        para = ParagraphStyle()
         para.set_font(font)
         para.set_description(_('The style used for headings.'))
         default_style.add_paragraph_style('REC-Heading', para)
 
-        font = BaseDoc.FontStyle()
-        font.set_type_face(BaseDoc.FONT_SANS_SERIF)
+        font = FontStyle()
+        font.set_type_face(FONT_SANS_SERIF)
         font.set_size(12)
         font.set_bold(1)
-        para = BaseDoc.ParagraphStyle()
+        para = ParagraphStyle()
         para.set_font(font)
-        para.set_description(_("The style used for the report title"))
+        para.set_description(_("The style used for the report title."))
         default_style.add_paragraph_style('REC-Title', para)
 
 #------------------------------------------------------------------------
@@ -550,32 +541,3 @@ RECORDS = [
         (_("Living couple married most long ago"),    'family_oldestmarried',    True),
         (_("Shortest past marriage"),          'family_shortest',         False),
         (_("Longest past marriage"),           'family_longest',          True)]
-
-
-#------------------------------------------------------------------------
-#
-# Register the gramplet and the report
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-register(
-        type="gramplet", 
-        name= "Records Gramplet", 
-        tname=_("Records Gramplet"), 
-        height=230,
-        expand=True,
-        content = RecordsGramplet,
-        title=_("Records"))
-
-pmgr.register_report(
-        name = 'records',
-        category = CATEGORY_TEXT,
-        report_class = RecordsReport,
-        options_class = RecordsReportOptions,
-        modes = MODE_GUI | MODE_BKI | MODE_CLI,
-        translated_name = _("Records Report"),
-        status = _("Stable"),
-        author_name = u"Reinhard Müller",
-        author_email = "reinhard.mueller@bytewise.at",
-        description = _(
-            "Shows some interesting records about people and families"))
