@@ -1,8 +1,8 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2007  Zsolt Foldvari
-# Copyright (C) 2008  Brian G. Matherly
+# Copyright (C) 2007       Zsolt Foldvari
+# Copyright (C) 2008-2009  Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: GtkPrint.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: GtkPrint.py 14284 2010-02-08 17:23:48Z ldnp $
 
 """Printing interface based on gtk.Print* classes.
 """
@@ -29,9 +29,9 @@
 # Python modules
 #
 #------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 from math import radians
-import os
+
 ##try:
     ##from cStringIO import StringIO
 ##except:
@@ -42,10 +42,11 @@ import os
 # Gramps modules
 #
 #------------------------------------------------------------------------
-import BaseDoc
-from CairoDoc import CairoDoc
-from gen.plug import PluginManager
+from gen.plug.docgen import PAPER_PORTRAIT
+import libcairodoc
 import Errors
+from glade import Glade
+#import constfunc
 
 #------------------------------------------------------------------------
 #
@@ -61,7 +62,6 @@ log = logging.getLogger(".GtkPrint")
 #
 #-------------------------------------------------------------------------
 import gtk
-from gtk import glade
 import cairo
 
 if gtk.pygtk_version < (2, 10, 0):
@@ -87,7 +87,7 @@ MARGIN = 6
 (ZOOM_BEST_FIT,
  ZOOM_FIT_WIDTH,
  ZOOM_FREE,) = range(3)
-
+ 
 #------------------------------------------------------------------------
 #
 # Converter functions
@@ -95,10 +95,10 @@ MARGIN = 6
 #------------------------------------------------------------------------
 
 def paperstyle_to_pagesetup(paper_style):
-    """Convert a BaseDoc.PaperStyle instance into a gtk.PageSetup instance.
+    """Convert a PaperStyle instance into a gtk.PageSetup instance.
     
     @param paper_style: Gramps paper style object to convert
-    @param type: BaseDoc.PaperStyle
+    @param type: PaperStyle
     @return: page_setup
     @rtype: gtk.PageSetup
     """
@@ -149,7 +149,7 @@ def paperstyle_to_pagesetup(paper_style):
     page_setup.set_paper_size(paper_size)
     
     # Set paper orientation
-    if paper_style.get_orientation() == BaseDoc.PAPER_PORTRAIT:
+    if paper_style.get_orientation() == PAPER_PORTRAIT:
         page_setup.set_orientation(gtk.PAGE_ORIENTATION_PORTRAIT)
     else:
         page_setup.set_orientation(gtk.PAGE_ORIENTATION_LANDSCAPE)
@@ -199,48 +199,31 @@ class PrintPreview(object):
     def __build_window(self):
         """Build the window from Glade.
         """
-        glade_file = os.path.join(os.path.dirname(__file__),
-                                  'gtkprintpreview.glade')
 
-        glade_xml = glade.XML(glade_file, 'window', 'gramps')
-        self._window = glade_xml.get_widget('window')
+        glade_xml = Glade()
+        self._window = glade_xml.toplevel
         #self._window.set_transient_for(parent)
  
         # remember active widgets for future use
-        self._swin = glade_xml.get_widget('swin')
-        self._drawing_area = glade_xml.get_widget('drawingarea')
-        self._first_button = glade_xml.get_widget('first')
-        self._prev_button = glade_xml.get_widget('prev')
-        self._next_button = glade_xml.get_widget('next')
-        self._last_button = glade_xml.get_widget('last')
-        self._pages_entry = glade_xml.get_widget('entry')
-        self._pages_label = glade_xml.get_widget('label')
-        self._zoom_fit_width_button = glade_xml.get_widget('zoom_fit_width')
+        self._swin = glade_xml.get_object('swin')
+        self._drawing_area = glade_xml.get_object('drawingarea')
+        self._first_button = glade_xml.get_object('first')
+        self._prev_button = glade_xml.get_object('prev')
+        self._next_button = glade_xml.get_object('next')
+        self._last_button = glade_xml.get_object('last')
+        self._pages_entry = glade_xml.get_object('entry')
+        self._pages_label = glade_xml.get_object('label')
+        self._zoom_fit_width_button = glade_xml.get_object('zoom_fit_width')
         self._zoom_fit_width_button.set_stock_id('gramps-zoom-fit-width')
-        self._zoom_best_fit_button = glade_xml.get_widget('zoom_best_fit')
+        self._zoom_best_fit_button = glade_xml.get_object('zoom_best_fit')
         self._zoom_best_fit_button.set_stock_id('gramps-zoom-best-fit')
-        self._zoom_in_button = glade_xml.get_widget('zoom_in')
+        self._zoom_in_button = glade_xml.get_object('zoom_in')
         self._zoom_in_button.set_stock_id('gramps-zoom-in')
-        self._zoom_out_button = glade_xml.get_widget('zoom_out')
+        self._zoom_out_button = glade_xml.get_object('zoom_out')
         self._zoom_out_button.set_stock_id('gramps-zoom-out')
 
         # connect the signals
-        glade_xml.signal_autoconnect({
-            'on_drawingarea_expose_event': self.on_drawingarea_expose_event,
-            'on_swin_size_allocate': self.on_swin_size_allocate,
-            'on_quit_clicked': self.on_quit_clicked,
-            'on_print_clicked': self.on_print_clicked,
-            'on_first_clicked': self.on_first_clicked,
-            'on_prev_clicked': self.on_prev_clicked,
-            'on_next_clicked': self.on_next_clicked,
-            'on_last_clicked': self.on_last_clicked,
-            'on_zoom_fit_width_toggled': self.on_zoom_fit_width_toggled,
-            'on_zoom_best_fit_toggled': self.on_zoom_best_fit_toggled,
-            'on_zoom_in_clicked': self.on_zoom_in_clicked,
-            'on_zoom_out_clicked': self.on_zoom_out_clicked,
-            'on_window_delete_event': self.on_window_delete_event,
-            'on_entry_activate': self.on_entry_activate,
-        })
+        glade_xml.connect_signals(self)
 
     ##def create_surface(self):
         ##return cairo.PDFSurface(StringIO(),
@@ -296,12 +279,12 @@ class PrintPreview(object):
         self._drawing_area.queue_draw()
         
         self._zoom_in_button.set_sensitive(self._zoom !=
-                                           max(self.zoom_factors.keys()))
+                                           max(self.zoom_factors))
         self._zoom_out_button.set_sensitive(self._zoom !=
-                                            min(self.zoom_factors.keys()))
+                                            min(self.zoom_factors))
         
     def __zoom_in(self):
-        zoom = [z for z in self.zoom_factors.keys() if z > self._zoom]
+        zoom = [z for z in self.zoom_factors if z > self._zoom]
 
         if zoom:
             return min(zoom)
@@ -309,7 +292,7 @@ class PrintPreview(object):
             return self._zoom
             
     def __zoom_out(self):
-        zoom = [z for z in self.zoom_factors.keys() if z < self._zoom]
+        zoom = [z for z in self.zoom_factors if z < self._zoom]
         
         if zoom:
             return max(zoom)
@@ -509,7 +492,7 @@ class PrintPreview(object):
 # GtkPrint class
 #
 #------------------------------------------------------------------------
-class GtkPrint(CairoDoc):
+class GtkPrint(libcairodoc.CairoDoc):
     """Print document via GtkPrint* interface.
     
     Requires Gtk+ 2.10.
@@ -599,7 +582,7 @@ class GtkPrint(CairoDoc):
     def on_preview(self, operation, preview, context, parent):
         """Implement custom print preview functionality.
         """
-        ##if os.sys.platform == 'win32':
+        ##if constfunc.win()':
             ##return False
             
         self.preview = PrintPreview(operation, preview, context, parent)
@@ -619,13 +602,3 @@ class GtkPrint(CairoDoc):
         context.set_cairo_context(cr, PRINTER_DPI, PRINTER_DPI)
         
         return True
-    
-#------------------------------------------------------------------------
-#
-# Register the document generator with the GRAMPS plugin system
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_text_doc(_('Print...'), GtkPrint, 1, 1, "", None)
-pmgr.register_draw_doc(_('Print...'), GtkPrint, 1, 1, "", None)
-pmgr.register_book_doc(_('Print...'), GtkPrint, 1, 1, "", None)
