@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ODFDoc.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: ODFDoc.py 15922 2010-09-23 21:03:02Z bmcage $
 
 """
 ODFDoc : used to generate Open Office Document
@@ -281,7 +281,7 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             self.cntnt.write('draw:fill-color="#%02x%02x%02x" ' %
                               style.get_fill_color())
             self.cntnt.write('draw:shadow="hidden" ')
-            self.cntnt.write('style:run-through="background" ')
+            self.cntnt.write('style:run-through="foreground" ')
             self.cntnt.write('style:vertical-pos="from-top" ')
             self.cntnt.write('style:vertical-rel="paragraph" ')
             self.cntnt.write('style:horizontal-pos="from-left" ')
@@ -302,7 +302,7 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             self.cntnt.write('draw:textarea-horizontal-align="center" ')
             self.cntnt.write('draw:textarea-vertical-align="middle" ')
             self.cntnt.write('draw:shadow="hidden" ')
-            self.cntnt.write('style:run-through="background" ')
+            self.cntnt.write('style:run-through="foreground" ')
             self.cntnt.write('style:vertical-pos="from-top" ')
             self.cntnt.write('style:vertical-rel="paragraph" ')
             self.cntnt.write('style:horizontal-pos="from-left" ')
@@ -318,7 +318,7 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         self.cntnt.write('style:family="graphic">\n')
         self.cntnt.write('<style:graphic-properties draw:stroke="none" ')
         self.cntnt.write('draw:fill="none" draw:shadow="hidden" ')
-        self.cntnt.write('style:run-through="background" ')
+        self.cntnt.write('style:run-through="foreground" ')
         self.cntnt.write('style:vertical-pos="from-top" ')
         self.cntnt.write('style:vertical-rel="paragraph" ')
         self.cntnt.write('style:horizontal-pos="from-left" ')
@@ -345,7 +345,7 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             if style.get_padding() != 0.0:
                 self.cntnt.write('fo:padding="%.2fcm" ' % style.get_padding())
             if style.get_header_level() > 0:
-                self.cntnt.write('fo:keep-with-next="true" ')
+                self.cntnt.write('fo:keep-with-next="auto" ')
 
             align = style.get_alignment()
             if align == PARA_ALIGN_LEFT:
@@ -381,8 +381,10 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
                              style.get_right_margin())
             self.cntnt.write('fo:margin-left="%.2fcm"\n' %
                              style.get_left_margin())
-            self.cntnt.write('fo:margin-top="0.00cm"\n')
-            self.cntnt.write('fo:margin-bottom="0.212cm" ')
+            self.cntnt.write('fo:margin-top="%.2fcm"\n' %
+                             style.get_top_margin())
+            self.cntnt.write('fo:margin-bottom="%.2fcm"\n' %
+                             style.get_bottom_margin())
             self.cntnt.write('/>\n')
             self.cntnt.write('</style:style>\n')
 
@@ -966,13 +968,15 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
                              style.get_left_margin())
             self.sfile.write('fo:margin-right="%.2fcm"\n' %
                              style.get_right_margin())
-            self.sfile.write('fo:margin-top="0.00cm"\n')
-            self.sfile.write('fo:margin-bottom="0.212cm"\n')
+            self.sfile.write('fo:margin-top="%.2fcm"\n' %
+                             style.get_top_margin())
+            self.sfile.write('fo:margin-bottom="%.2fcm"\n' %
+                             style.get_bottom_margin())
 
             if style.get_padding() != 0.0:
                 self.sfile.write('fo:padding="%.2fcm" ' % style.get_padding())
             if style.get_header_level() > 0:
-                self.sfile.write('fo:keep-with-next="always" ')
+                self.sfile.write('fo:keep-with-next="auto" ')
 
             align = style.get_alignment()
             if align == PARA_ALIGN_LEFT:
@@ -1011,8 +1015,10 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
                                  style.get_right_margin())
                 self.sfile.write('fo:margin-left="%.2fcm" ' %
                                  style.get_left_margin())
-                self.sfile.write('fo:margin-top="0cm" ')
-                self.sfile.write('fo:margin-bottom="0.212cm"')
+                self.sfile.write('fo:margin-top="%.2fcm"\n' %
+                                 style.get_top_margin())
+                self.sfile.write('fo:margin-bottom="%.2fcm"\n' %
+                                 style.get_bottom_margin())
             self.sfile.write('/>\n')
             self.sfile.write('</style:style>\n')
 
@@ -1202,19 +1208,24 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             self.cntnt.write('</text:span>')
             self.end_paragraph()
 
-    def write_styled_note(self, styledtext, format, style_name):
+    def write_styled_note(self, styledtext, format, style_name,
+                          contains_html=False):
         """
-        Convenience function to write a styledtext to the latex doc. 
+        Convenience function to write a styledtext to the ODF doc. 
         styledtext : assumed a StyledText object to write
         format : = 0 : Flowed, = 1 : Preformatted
         style_name : name of the style to use for default presentation
+        contains_html: bool, the backend should not check if html is present. 
+            If contains_html=True, then the textdoc is free to handle that in 
+            some way. Eg, a textdoc could remove all tags, or could make sure
+            a link is clickable. ODFDoc prints the html without handling it
         """
         text = str(styledtext)
         s_tags = styledtext.get_tags()
         text = text.replace('&', '\1') # must be the first
         text = text.replace('<', '\2')
         text = text.replace('>', '\3')
-        markuptext = self._backend.add_markup_from_styled(text, s_tags)
+        markuptext = self._backend.add_markup_from_styled(text, s_tags, '\n')
         # we need to know if we have new styles to add.
         # if markuptext contains : FontColor, FontFace, FontSize ...
         # we must prepare the new styles for the styles.xml file.
@@ -1236,10 +1247,16 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         markuptext = markuptext.replace('\2', '&lt;')
         markuptext = markuptext.replace('\3', '&gt;')
         for line in markuptext.split('\n'):
-            if ( linenb > 1 ):
-                self.cntnt.write('<text:line-break/>')
-            self.cntnt.write(line)
-            linenb += 1
+            [line, sigcount] = process_spaces(line, format)
+            if sigcount == 0:
+                self.end_paragraph()
+                self.start_paragraph(style_name)
+                linenb = 1
+            else:
+                if ( linenb > 1 ):
+                    self.cntnt.write('<text:line-break/>')
+                self.cntnt.write(line)
+                linenb += 1
         self.end_paragraph()
 
     def write_text(self, text, mark=None):
@@ -1537,3 +1554,48 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             self.cntnt.write('</text:p>\n')
             self.cntnt.write('</draw:text-box>')
         self.cntnt.write('</draw:frame>\n')
+
+def process_spaces(line, format):
+    """
+    Function to process spaces in text lines for flowed and pre-formatted notes.
+    line : text to process
+    format : = 0 : Flowed, = 1 : Preformatted
+    
+    If the text is flowed (format==0), then leading spaces (after ignoring XML)
+    are removed. Embedded multiple spaces are reduced to one by ODF
+    If the text is pre-formatted (format==1). then all spaces  (after ignoring XML)
+    are replaced by "<text:s/>"
+    
+    Returns the processed text, and the number of significant (i.e. non-white-space) chars.
+    """
+    txt = ""
+    xml = False
+    sigcount = 0
+    # we loop through every character, which is very inefficient, but an attempt to use
+    # a regex replace didn't always work. This was the code that was replaced.
+    # Problem, we may not replace ' ' in xml tags, so we use a regex
+    # self.cntnt.write(re.sub(' (?=([^(<|>)]*<[^>]*>)*[^>]*$)', 
+    #                        "<text:s/>", line))
+    for char in line:
+        if char == '<' and xml == False:
+            xml = True
+            txt += char
+        elif char == '>' and xml == True:
+            xml = False
+            txt += char
+        elif xml == True:
+            txt += char
+        elif char == " " or char == "\t":
+            if format == 0 and sigcount == 0:
+                pass
+            elif format == 1:
+                #preformatted, section White-space characters of
+                # http://docs.oasis-open.org/office/v1.1/OS/OpenDocument-v1.1-html/OpenDocument-v1.1.html#5.1.1.White-space%20Characters|outline
+                txt += "<text:s/>"
+            else:
+                txt += char
+        else:
+            sigcount += 1
+            txt += char
+    return [txt, sigcount]
+    
\ No newline at end of file
