@@ -10,6 +10,7 @@
 #    Contributions by Lorenzo Cappelletti <lorenzo.cappelletti@email.it>
 #    Copyright (C) 2008       Stephane Charette <stephanecharette@gmail.com>
 #    Copyright (C) 2009       Gary Burton
+#    Contribution 2009 by     Bob Ham <rah@bash.sh>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +27,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: GVRelGraph.py 12595 2009-05-30 11:58:03Z gburto01 $
+# $Id: GVRelGraph.py 14156 2010-01-28 15:20:19Z ldnp $
 
 """
 Create a relationship graph using Graphviz
@@ -37,22 +38,22 @@ Create a relationship graph using Graphviz
 # python modules
 #
 #------------------------------------------------------------------------
-from TransUtils import sgettext as _
+from gen.ggettext import sgettext as _
 
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-from gen.plug import PluginManager
 from gen.plug.menu import BooleanOption, EnumeratedListOption, FilterOption, \
                           PersonOption, ColorOption
-from ReportBase import Report, ReportUtils, MenuReportOptions, CATEGORY_GRAPHVIZ
-from BasicUtils import name_displayer
+from ReportBase import Report, ReportUtils, MenuReportOptions
+from gen.display.name import displayer as name_displayer
 import DateHandler
 import gen.lib
 import Utils
 import ThumbNails
+from gen.utils import get_birth_or_fallback, get_death_or_fallback
 
 #------------------------------------------------------------------------
 #
@@ -140,11 +141,11 @@ class RelGraphReport(Report):
         }
 
         arrow_str = menu.get_option_by_name('arrow').get_value()
-        if arrow_str.find('a') + 1:
+        if 'd' in arrow_str:
             self.arrowheadstyle = 'normal'
         else:
             self.arrowheadstyle = 'none'
-        if arrow_str.find('d') + 1:
+        if 'a' in arrow_str:
             self.arrowtailstyle = 'normal'
         else:
             self.arrowtailstyle = 'none'
@@ -153,7 +154,7 @@ class RelGraphReport(Report):
 
     def write_report(self):
         self.person_handles = self._filter.apply(self.database,
-                    self.database.get_person_handles(sort_handles=False))
+                    self.database.iter_person_handles())
         
         if len(self.person_handles) > 1:
             self.add_persons_and_families()
@@ -162,10 +163,9 @@ class RelGraphReport(Report):
     def add_child_links_to_families(self):
         "returns string of GraphViz edges linking parents to families or \
          children"
-        person_dict = {}
         # Hash people in a dictionary for faster inclusion checking
-        for person_handle in self.person_handles:
-            person_dict[person_handle] = 1
+        person_dict = dict([handle, 1] for handle in self.person_handles)
+            
         for person_handle in self.person_handles:
             person = self.database.get_person_from_handle(person_handle)
             p_id = person.get_gramps_id()
@@ -195,14 +195,14 @@ class RelGraphReport(Report):
         style = 'solid'
         adopted = ((int(frel) != gen.lib.ChildRefType.BIRTH) or
                    (int(mrel) != gen.lib.ChildRefType.BIRTH))
-        # If birth relation to father is NONE, mening there is no father and
+        # If birth relation to father is NONE, meaning there is no father and
         # if birth relation to mother is BIRTH then solid line
         if ((int(frel) == gen.lib.ChildRefType.NONE) and
            (int(mrel) == gen.lib.ChildRefType.BIRTH)):
             adopted = False
         if adopted and self.adoptionsdashed:
             style = 'dotted'
-        self.doc.add_link( p_id, family.get_gramps_id(), style, 
+        self.doc.add_link( family.get_gramps_id(), p_id, style,  
                            self.arrowheadstyle, self.arrowtailstyle )
         
     def add_parent_link(self, p_id, parent_handle, rel):
@@ -211,7 +211,7 @@ class RelGraphReport(Report):
         if (int(rel) != gen.lib.ChildRefType.BIRTH) and self.adoptionsdashed:
             style = 'dotted'
         parent = self.database.get_person_from_handle(parent_handle)
-        self.doc.add_link( p_id, parent.get_gramps_id(), style, 
+        self.doc.add_link( parent.get_gramps_id(), p_id, style,
                            self.arrowheadstyle, self.arrowtailstyle )
         
     def add_persons_and_families(self):
@@ -234,7 +234,7 @@ class RelGraphReport(Report):
             url = ""
             if self.includeurl:
                 h = person_handle
-                dirpath = "ppl/%s/%s" % (h[0], h[1])
+                dirpath = "ppl/%s/%s" % (h[-1], h[-2])
                 dirpath = dirpath.lower()
                 url = "%s/%s.html" % (dirpath, h)
                 
@@ -245,7 +245,6 @@ class RelGraphReport(Report):
                 family_list = person.get_family_handle_list()
                 for fam_handle in family_list:
                     family = self.database.get_family_from_handle(fam_handle)
-                    fam_id = family.get_gramps_id()
                     if fam_handle not in families_done:
                         families_done[fam_handle] = 1
                         self.__add_family(fam_handle)
@@ -254,7 +253,7 @@ class RelGraphReport(Report):
                     # control over the layout of the whole graph but
                     # may leave spouses not positioned together.
                     if not self.use_subgraphs:
-                        self.doc.add_link(fam_id, p_id, "",
+                        self.doc.add_link(p_id, family.get_gramps_id(), "",
                                           self.arrowheadstyle,
                                           self.arrowtailstyle)
                         
@@ -266,7 +265,9 @@ class RelGraphReport(Report):
         label = ""
         for event_ref in fam.get_event_ref_list():
             event = self.database.get_event_from_handle(event_ref.ref)
-            if event.type == gen.lib.EventType.MARRIAGE:
+            if event.type == gen.lib.EventType.MARRIAGE and \
+            (event_ref.get_role() == gen.lib.EventRoleType.FAMILY or 
+            event_ref.get_role() == gen.lib.EventRoleType.PRIMARY ):
                 label = self.get_event_string(event)
                 break
         if self.includeid:
@@ -292,14 +293,14 @@ class RelGraphReport(Report):
             m_handle = fam.get_mother_handle()
             if f_handle:
                 father = self.database.get_person_from_handle(f_handle)
-                self.doc.add_link(fam_id,
-                                  father.get_gramps_id(), "", 
+                self.doc.add_link(father.get_gramps_id(),
+                                  fam_id, "", 
                                   self.arrowheadstyle,
                                   self.arrowtailstyle)
             if m_handle:
                 mother = self.database.get_person_from_handle(m_handle)
-                self.doc.add_link(fam_id,
-                                  mother.get_gramps_id(), "", 
+                self.doc.add_link(mother.get_gramps_id(),
+                                  fam_id, "", 
                                   self.arrowheadstyle,
                                   self.arrowtailstyle)
             self.doc.end_subgraph()
@@ -347,7 +348,8 @@ class RelGraphReport(Report):
                 if mediaMimeType[0:5] == "image":
                     imagePath = ThumbNails.get_thumbnail_path(
                                     Utils.media_path_full(self.database, 
-                                                          media.get_path()))
+                                                          media.get_path()),
+                                        rectangle=mediaList[0].get_rectangle())
                     # test if thumbnail actually exists in thumbs
                     # (import of data means media files might not be present
                     imagePath = Utils.find_file(imagePath)
@@ -360,7 +362,7 @@ class RelGraphReport(Report):
         #
         # This isn't a free-form HTML format here...just a few keywords that
         # happen to be
-        # simillar to keywords commonly seen in HTML.  For additional
+        # similar to keywords commonly seen in HTML.  For additional
         # information on what
         # is allowed, see:
         #
@@ -397,18 +399,18 @@ class RelGraphReport(Report):
             label += '</TD></TR></TABLE>'
             return label
         else :
-            # non html label is enclosed by "" so excape other "
+            # non html label is enclosed by "" so escape other "
             return label.replace('"', '\\\"')
     
     def get_date_strings(self, person):
         "returns tuple of birth/christening and death/burying date strings"
-        birth_event = ReportUtils.get_birth_or_fallback(self.database, person)
+        birth_event = get_birth_or_fallback(self.database, person)
         if birth_event:
             birth = self.get_event_string(birth_event)
         else:
             birth = ""
 
-        death_event = ReportUtils.get_death_or_fallback(self.database, person)
+        death_event = get_death_or_fallback(self.database, person)
         if death_event:
             death = self.get_event_string(death_event)
         else:
@@ -612,26 +614,3 @@ class RelGraphOptions(MenuReportOptions):
         image location option unavailable.
         """
         self.__image_on_side.set_available(self.__include_images.get_value())
-
-#------------------------------------------------------------------------
-#
-# 
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_report(
-    name            = 'rel_graph',
-    category        = CATEGORY_GRAPHVIZ,
-    report_class    = RelGraphReport,
-    options_class   = RelGraphOptions,
-    modes           = PluginManager.REPORT_MODE_GUI | \
-                      PluginManager.REPORT_MODE_CLI,
-    translated_name = _("Relationship Graph"),
-    status          = _("Stable"),
-    description     = _("Produces relationship graphs using Graphviz"),
-    author_name     = "Brian G. Matherly",
-    author_email    = "brian@gramps-project.org"
-    )
-
-
-
